.. Django_Harman documentation master file, created by
   sphinx-quickstart on Tue Jan 28 16:29:36 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Django_Harman's documentation!
=========================================

This is a simple in use but highly complex in its
development django library...Huuray feel free to
contribute.Tests (TDD) are a must in any code i write.

Contents:

.. toctree::
   :maxdepth: 2

   01-testing



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
